@@ -1,6 +1,10 @@
+import logging
+
 from entrypoint2 import entrypoint
 
-import pyscreenshot
+from pyscreenshot.loader import backend_version2
+
+log = logging.getLogger(__name__)
 
 
 @entrypoint
@@ -10,5 +14,10 @@ def main(backend):
     :param backend: back-end (example:scrot, wx,..)
     """
     backend = backend if backend else None
-    v = pyscreenshot.backend_version(backend=backend, childprocess=False)
+
+    try:
+        v = backend_version2(backend)
+    except Exception as e:
+        log.warning(e)
+        v = ""
     print(v)
