@@ -3,7 +3,6 @@ import traceback
 
 from pyscreenshot.childproc import childprocess_grab
 from pyscreenshot.err import FailedBackendError
-from pyscreenshot.plugins import backend_dict
 from pyscreenshot.plugins.gdk3pixbuf import Gdk3PixbufWrapper
 from pyscreenshot.plugins.gnome_dbus import GnomeDBusWrapper
 from pyscreenshot.plugins.gnome_screenshot import GnomeScreenshotWrapper
@@ -31,7 +30,26 @@ from pyscreenshot.util import (
 log = logging.getLogger(__name__)
 
 
-log = logging.getLogger(__name__)
+backend_dict = {
+    PilWrapper.name: PilWrapper,
+    MssWrapper.name: MssWrapper,
+    ScrotWrapper.name: ScrotWrapper,
+    GrimWrapper.name: GrimWrapper,
+    MaimWrapper.name: MaimWrapper,
+    ImagemagickWrapper.name: ImagemagickWrapper,
+    Qt5GrabWindow.name: Qt5GrabWindow,
+    Qt4GrabWindow.name: Qt4GrabWindow,
+    PySide2GrabWindow.name: PySide2GrabWindow,
+    PySideGrabWindow.name: PySideGrabWindow,
+    WxScreen.name: WxScreen,
+    Gdk3PixbufWrapper.name: Gdk3PixbufWrapper,
+    ScreencaptureWrapper.name: ScreencaptureWrapper,
+    MacQuartzWrapper.name: MacQuartzWrapper,
+    GnomeDBusWrapper.name: GnomeDBusWrapper,
+    GnomeScreenshotWrapper.name: GnomeScreenshotWrapper,
+    KwinDBusWrapper.name: KwinDBusWrapper,
+    # XwdWrapper.name: XwdWrapper,
+}
 
 
 def qt():
@@ -70,30 +88,23 @@ def backends(childprocess):
         yield GrimWrapper
 
     elif platform_is_osx():
-        # first check for X
-        if use_x_display():
-            pass
-        else:
-            # fast
-            yield MssWrapper
-
-            # latest version should work
-            yield PilWrapper
-
-            # alternatives for older pillow versions
-            yield ScreencaptureWrapper
-            yield MacQuartzWrapper
-
-            # qt has some color difference
-
-            # does not work: Gdk3, wx, Imagemagick
-
-    elif platform_is_win():
-        # fast
+        yield PilWrapper
         yield MssWrapper
 
+        # alternatives for older pillow versions
+        yield ScreencaptureWrapper
+        yield MacQuartzWrapper
+
+        # qt has some color difference
+
+        # does not work: Gdk3, wx, Imagemagick
+
+    elif platform_is_win():
         yield PilWrapper
+        yield MssWrapper
     else:
+        yield PilWrapper
+        yield MssWrapper
         for x in backend_dict.values():
             yield x
 
