@@ -1,19 +1,9 @@
+import io
 import logging
 
 from PIL import Image
 
 from pyscreenshot.plugins.backend import CBackend
-from pyscreenshot.util import py2
-
-if py2():
-    import StringIO
-
-    BytesIO = StringIO.StringIO
-else:
-    import io
-
-    BytesIO = io.BytesIO
-
 
 log = logging.getLogger(__name__)
 
@@ -25,9 +15,6 @@ app = None
 class PySideGrabWindow(CBackend):
     name = "pyside"
 
-    def __init__(self):
-        pass
-
     def grab_to_buffer(self, buff, file_type="png"):
         from PySide import QtGui
         from PySide import QtCore
@@ -48,7 +35,7 @@ class PySideGrabWindow(CBackend):
         qbuffer.close()
 
     def grab(self, bbox=None):
-        strio = BytesIO()
+        strio = io.BytesIO()
         self.grab_to_buffer(strio)
         strio.seek(0)
         im = Image.open(strio)
